
.. note::

   This page is a reference documentation. It only explains the class
   signature, and not how to use it. Please refer to the
   :ref:`user guide <quickstart>` for the big picture.


{{ fullname }}
{{ underline }}

.. currentmodule:: {{ module }}

.. autoclass:: {{ objname }}
   :inherited-members:

   {% block methods %}
   .. automethod:: __init__
   {% endblock %}

.. include:: {{module}}.{{objname}}.examples

.. raw:: html

    <div style='clear:both'></div>
